yakumo.nova.v2.interface_attachment.Manager

Package yakumo :: Package nova :: Package v2 :: Module interface_attachment :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
     base.SubManager --+
                       |
                      Manager

Manager class for interface attachment in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for interface attachment in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.interface_attachment.Resource |
attach(self, port=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`) Attach a interface | source code
Inherited from `base.SubManager`: `__init__` Inherited from `base.Manager`: `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``port``'``,` `'``port_id``'``,` <yakumo.mapper.Resource o`...``
| _hidden_methods = ``[``'``create``'``,` `'``update``'``,` `'``delete``'``]``
| _json_resource_key = ``'``interfaceAttachment``'``
| _json_resources_key = ``'``interfaceAttachments``'``
| _url_resource_path = ``'``/servers/%s/os-interface``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### attach(self, port=`'``__UNDEF__``'`, network=`'``__UNDEF__``'`, fixed_ips=`'``__UNDEF__``'`) | source code
Attach a interface Parameters: `port` (yakumo.neutron.v2.port.Resource) - Port `network` (yakumo.neutron.v2.network.Resource) - Network `fixed_ips` ([yakumo.neutron.v2.fixed_ip.Resource]) - list of fixed ips (required if network= exists) Returns: yakumo.nova.v2.interface_attachment.Resource Interface attachment

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('port', 'port_id', mapper.Resource('port')), ('id', 'port_id', mappe
      r.Resource('port')), ('network', 'net_id', mapper.Resource('network'))
      , ('mac_addr', 'mac_addr', mapper.Noop), ('fixed_ips', 'fixed_ips', ma
      pper.Noop), ('status', 'port_state', mapper.Noop),]